@@ -26,7 +26,7 @@ beta  <- 1 - 2/3*( w1*w3) /(w2^2)
 
 #@ equation 10 of Chen and Deo @
 
-tem <- complex(imag=-lamda)
+tem <- complex(imaginary=-lamda)
 Ilamda <- matrix(NA,nrow=nrow(lamda),1)
 for( j in 1:nrow(lamda) )
 {
@@ -97,4 +97,3 @@ QP <- t(Vp-mubeta) %*% solve(sigbeta) %*% (Vp-mubeta)
 crit <- qchisq(c(0.01,0.02,0.05,0.10,0.20),df=length(kvec),lower.tail=FALSE)
 return(list(Holding.Period=kvec,VRsum=stat1,QPn=QP,ChiSQ.Quantiles_1_2_5_10_20_percent=crit))
 }
-
